Official Rockset Python Client
==============================

A Python library for Rockset's API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install rockset


Using the Rockset API
---------------------

Documentation for this library can be found here:

- https://github.com/rockset/rockset-python-client
